@@ -1,5 +1,5 @@
 /*
- * Copyright 1995-1999 Bruno Haible, <haible@clisp.cons.org>
+ * Copyright 1995-1999 Bruno Haible, <bruno@clisp.org>
  *
  * This is free software distributed under the GNU General Public Licence
  * described in the file COPYING. Contact the author if you don't have this
@@ -8,6 +8,7 @@
  */
 
 #include <stdio.h>
+#include <stdlib.h>
 
 #include "vacall_r.h"
 #include "config.h"
@@ -15,12 +16,6 @@
 /* Room for returning structs according to the pcc non-reentrant struct return convention. */
 __va_struct_buffer_t __va_struct_buffer;
 
-#ifdef __cplusplus
-extern "C" ABORT_VOLATILE RETABORTTYPE abort ();
-#else
-extern ABORT_VOLATILE RETABORTTYPE abort ();
-#endif
-
 int /* no return type, since this never returns */
 #if defined(__STDC__) || defined(__GNUC__) || defined(__cplusplus)
 __va_error1 (enum __VAtype start_type, enum __VAtype return_type)
