@@ -1,7 +1,7 @@
 /* Trampoline accessor test */
 
 /*
- * Copyright 1995-1999 Bruno Haible, <haible@clisp.cons.org>
+ * Copyright 1995-1999, 2002 Bruno Haible, <bruno@clisp.org>
  *
  * This is free software distributed under the GNU General Public Licence
  * described in the file COPYING. Contact the author if you don't have this
@@ -14,7 +14,11 @@
 
 #include "trampoline.h"
 
+#ifdef __cplusplus
+typedef int (*function)(...);
+#else
 typedef int (*function)();
+#endif
 
 #if defined(__STDC__) || defined(__GNUC__) || defined(__cplusplus)
 int f (int x)
@@ -30,16 +34,16 @@ static int data;
 
 int main ()
 {
-  function cf = alloc_trampoline(&f, &variable, &data);
-  if (is_trampoline(&main))
+  function cf = alloc_trampoline((function)&f, &variable, &data);
+  if (is_trampoline((void*)&main))
     { printf("is_trampoline(&main) returns true!\n"); exit(1); }
-  if (!is_trampoline(cf))
+  if (!is_trampoline((void*)cf))
     { printf("is_trampoline() returns false!\n"); exit(1); }
-  if (trampoline_address(cf) != &f)
+  if (trampoline_address((void*)cf) != (function)&f)
     { printf("trampoline_address() doesn't work!\n"); exit(1); }
-  if (trampoline_variable(cf) != &variable)
+  if (trampoline_variable((void*)cf) != &variable)
     { printf("trampoline_variable() doesn't work!\n"); exit(1); }
-  if (trampoline_data(cf) != &data)
+  if (trampoline_data((void*)cf) != &data)
     { printf("trampoline_data() doesn't work!\n"); exit(1); }
   printf("test2 passed.\n");
   exit(0);
