@@ -873,8 +873,8 @@
 ;    (:arguments (x double-float) (iptr (c-ptr double-float) :out))
 ;  (:return-type double-float))
 (def-call-out rint (:arguments (x double-float)) (:return-type double-float))
-(def-call-out scalb (:arguments (x double-float) (n double-float))
-  (:return-type double-float))
+;(def-call-out scalb (:arguments (x double-float) (n double-float))
+;  (:return-type double-float))
 (def-call-out nextafter (:arguments (x double-float) (y double-float))
   (:return-type double-float))
 (def-call-out remainder (:arguments (x double-float) (y double-float))
@@ -964,8 +964,8 @@
 ;    (:arguments (x single-float) (iptr (c-ptr single-float) :out))
 ;  (:return-type single-float))
 (def-call-out rintf (:arguments (x single-float)) (:return-type single-float))
-(def-call-out scalbf (:arguments (x single-float) (n single-float))
-  (:return-type single-float))
+;(def-call-out scalbf (:arguments (x single-float) (n single-float))
+;  (:return-type single-float))
 (def-call-out nextafterf (:arguments (x single-float) (y single-float))
   (:return-type single-float))
 (def-call-out remainderf (:arguments (x single-float) (y single-float))
@@ -1060,11 +1060,14 @@
 (def-call-out close (:arguments (fd int)) (:return-type int))
 
 (def-call-out read-helper
-    (:arguments (fd int) (buf c-pointer) (nbytes size_t) (partial-p boolean))
+    (:arguments (fd int) (buf c-pointer) (nbytes size_t) (no-hang-p boolean))
   (:return-type ssize_t) (:name "read_helper"))
-(defmacro read (fd buf nbytes) `(read-helper ,fd ,buf ,nbytes t))
-(def-call-out write (:arguments (fd int) (buf c-pointer) (nbytes size_t))
-  (:return-type ssize_t) (:name "full_write"))
+(defmacro read (fd buf nbytes) `(read-helper ,fd ,buf ,nbytes nil))
+(def-call-out write-helper
+    (:arguments (fd int) (buf (c-ptr (c-array-max char 4096)) :out :alloca)
+                (nbytes size_t) (no-hang-p boolean))
+  (:return-type ssize_t) (:name "write_helper"))
+(defmacro write (fd buf nbytes) `(write-helper ,fd ,buf ,nbytes nil))
 
 (def-call-out pipe (:arguments (pipedes (c-ptr (c-array int 2)) :out))
   (:return-type int))
@@ -2329,6 +2332,9 @@
     (:arguments (fd int) (request int) (arg (c-ptr int) :out :alloca))
   (:return-type int) (:name "ioctl"))
 
+;;; =============================== <signal.h> ===============================
+(c-lines "#include <signal.h>~%")
+
 ;;; --------------------------------- <bits/signum.h> ------------------------
 ;;;  --- Posix sigaction ---
 ;;;  Peter Wood 2002
