@@ -1,8 +1,9 @@
 ;;; handle the posix functions
-;;; Sam Steingold 1999-2003
+;;; Sam Steingold 1999-2004
 
 (defpackage "POSIX"
   (:use "COMMON-LISP" "EXT")
+  (:nicknames "OS")
   (:export
    "RESOLVE-HOST-IPADDR" "BOGOMIPS"
    "STREAM-LOCK" "DUPLICATE-HANDLE" "COPY-FILE"
@@ -73,6 +74,33 @@
 
 )
 
+;;; ============================================================
+#+unix (progn
+(export
+ '(stat-vfs stat-vfs-file stat-vfs-bsize stat-vfs-stat-vfs-frsize
+   stat-vfs-stat-vfs-blocks stat-vfs-stat-vfs-bfree stat-vfs-stat-vfs-bavail
+   stat-vfs-stat-vfs-files stat-vfs-stat-vfs-ffree stat-vfs-stat-vfs-favail
+   stat-vfs-stat-vfs-fsid stat-vfs-stat-vfs-flag stat-vfs-namemax))
+
+(defstruct (stat-vfs
+             (:constructor
+              make-stat-vfs (file bsize frsize blocks bfree bavail files
+                             ffree favail fsid flag namemax)))
+  (file  nil :read-only t)
+  (bsize   0 :type (unsigned-byte 32) :read-only t)
+  (frsize  0 :type (unsigned-byte 32) :read-only t)
+  (blocks  0 :type (unsigned-byte 32) :read-only t)
+  (bfree   0 :type (unsigned-byte 32) :read-only t)
+  (bavail  0 :type (unsigned-byte 32) :read-only t)
+  (files   0 :type (unsigned-byte 32) :read-only t)
+  (ffree   0 :type (unsigned-byte 32) :read-only t)
+  (favail  0 :type (unsigned-byte 32) :read-only t)
+  (fsid    0 :type (unsigned-byte 32) :read-only t)
+  (flag    0 :type (unsigned-byte 32) :read-only t)
+  (namemax 0 :type (unsigned-byte 32) :read-only t))
+
+)
+
 ;;; ============================================================
 #+unix (progn
 (export
@@ -109,6 +137,42 @@
 (setf (documentation 'sysconf 'function)
       "Return an instance of the SYSCONF structure.
 NIL - no such key; T - sysconf(3c) returned -1.")
+
+(export
+ '(confstr confstr-path confstr-ilp32-off32-cflags confstr-ilp32-off32-ldflags
+   confstr-ilp32-off32-libs confstr-ilp32-offbig-cflags
+   confstr-ilp32-offbig-ldflags confstr-ilp32-offbig-libs
+   confstr-lp64-off64-cflags confstr-lp64-off64-ldflags
+   confstr-lp64-off64-libs confstr-lpbig-offbig-cflags
+   confstr-lpbig-offbig-ldflags confstr-lpbig-offbig-libs
+   confstr-width-restricted-envs))
+(defstruct (confstr (:constructor
+                     make-confstr (path ilp32-off32-cflags ilp32-off32-ldflags
+                                   ilp32-off32-libs ilp32-offbig-cflags
+                                   ilp32-offbig-ldflags ilp32-offbig-libs
+                                   lp64-off64-cflags lp64-off64-ldflags
+                                   lp64-off64-libs lpbig-offbig-cflags
+                                   lpbig-offbig-ldflags lpbig-offbig-libs
+                                   width-restricted-envs)))
+  "see confstr(3c) for details"
+  (path nil :type (or boolean string) :read-only t)
+  (ilp32-off32-cflags nil :type (or boolean string) :read-only t)
+  (ilp32-off32-ldflags nil :type (or boolean string) :read-only t)
+  (ilp32-off32-libs nil :type (or boolean string) :read-only t)
+  (ilp32-offbig-cflags nil :type (or boolean string) :read-only t)
+  (ilp32-offbig-ldflags nil :type (or boolean string) :read-only t)
+  (ilp32-offbig-libs nil :type (or boolean string) :read-only t)
+  (lp64-off64-cflags nil :type (or boolean string) :read-only t)
+  (lp64-off64-ldflags nil :type (or boolean string) :read-only t)
+  (lp64-off64-libs nil :type (or boolean string) :read-only t)
+  (lpbig-offbig-cflags nil :type (or boolean string) :read-only t)
+  (lpbig-offbig-ldflags nil :type (or boolean string) :read-only t)
+  (lpbig-offbig-libs nil :type (or boolean string) :read-only t)
+  (width-restricted-envs nil :type (or boolean string) :read-only t))
+
+(setf (documentation 'confstr 'function)
+      "Return an instance of the CONFSTR structure.
+NIL - no such key; T - the parameter is not set.")
 )
 ;;; ============================================================
 #+unix (progn
@@ -199,6 +263,50 @@ NIL - no such key; T - sysconf(3c) returned -1.")
   (hot-key nil :read-only t)
   (stat nil :read-only t))
 
+(export '(system-info system-info-processor-architecture system-info-page-size
+          system-info-minimum-application-address
+          system-info-maximum-application-address
+          system-info-active-processor-mask system-info-number-of-processors
+          system-info-allocation-granularity
+          system-info-processor-level system-info-processor-revision))
+
+(defstruct (system-info
+             (:constructor make-system-info
+                           (processor-architecture page-size
+                            minimum-application-address
+                            maximum-application-address
+                            active-processor-mask number-of-processors
+                            allocation-granularity
+                            processor-level processor-revision)))
+  (processor-architecture nil :read-only t)
+  (page-size nil :read-only t)
+  (minimum-application-address nil :read-only t)
+  (maximum-application-address nil :read-only t)
+  (active-processor-mask nil :read-only t)
+  (number-of-processors nil :read-only t)
+  (allocation-granularity nil :read-only t)
+  (processor-level nil :read-only t)
+  (processor-revision nil :read-only t))
+
+(export '(version version-major version-minor version-build version-platform
+          version-service-pack version-service-pack-major
+          version-service-pack-minor version-suites version-product-type))
+
+(defstruct (version
+             (:constructor make-version
+                           (major minor build platform service-pack
+                            service-pack-major service-pack-minor
+                            suites product-type)))
+  (major nil :read-only t)
+  (minor nil :read-only t)
+  (build nil :read-only t)
+  (platform nil :read-only t)
+  (service-pack nil :read-only t)
+  (service-pack-major nil :read-only t)
+  (service-pack-minor nil :read-only t)
+  (suites nil :read-only t)
+  (product-type nil :read-only t))
+
 )
 
 ;;; restore locks
