@@ -35,9 +35,8 @@
 
 ;;; macros for packages (Chapter 11), p. 187-188
 (defmacro do-symbols ((var &optional (packageform '*package*) (resultform nil))
-                      &body body &environment env)
-  (multiple-value-bind (body-rest declarations)
-      (system::parse-body body nil env)
+                      &body body)
+  (multiple-value-bind (body-rest declarations) (system::parse-body body)
     (let ((packvar (gensym)))
       `(BLOCK NIL
          (LET ((,packvar ,packageform))
@@ -52,9 +51,8 @@
 
 (defmacro do-external-symbols ((var &optional (packageform '*package*)
                                     (resultform nil))
-                               &body body &environment env)
-  (multiple-value-bind (body-rest declarations)
-      (system::parse-body body nil env)
+                               &body body)
+  (multiple-value-bind (body-rest declarations) (system::parse-body body)
     (let ((packvar (gensym)))
       `(BLOCK NIL
          (LET ((,packvar ,packageform))
@@ -67,10 +65,8 @@
                ,packvar)
              ,resultform))))))
 
-(defmacro do-all-symbols ((var &optional (resultform nil))
-                          &body body &environment env)
-  (multiple-value-bind (body-rest declarations)
-      (system::parse-body body nil env)
+(defmacro do-all-symbols ((var &optional (resultform nil)) &body body)
+  (multiple-value-bind (body-rest declarations) (system::parse-body body)
     `(BLOCK NIL
        (LET ((,var NIL))
          (DECLARE (IGNORABLE ,var) ,@declarations)
@@ -118,7 +114,7 @@
 (defvar *system-package-list*
   '("SYSTEM" "LISP" "EXT" "CUSTOM" "I18N" "GRAY" "CHARSET" "CLOS"
     #+sockets "SOCKET" #+generic-streams "GSTREAM" #+syscalls "POSIX"
-    #+ffi "FFI" #+amiga "AFFI" #+screen "SCREEN"))
+    #+ffi "FFI" #+(or) "AFFI" #+screen "SCREEN"))
 
 ;; Unlock the specified packages, execute the BODY, then lock them again.
 (defmacro without-package-lock (packages &body body)
@@ -200,10 +196,8 @@
 
 ;;; functions for sequences (Chapter 14)
 
-(defmacro doseq ((var seqform &optional resultform) &body body
-                 &environment env)
-  (multiple-value-bind (body-rest declarations)
-      (system::parse-body body nil env)
+(defmacro doseq ((var seqform &optional resultform) &body body)
+  (multiple-value-bind (body-rest declarations) (system::parse-body body)
     (let ((seqvar (gensym)))
       `(BLOCK NIL
          (LET ((,seqvar ,seqform))
@@ -362,10 +356,8 @@
 
 ;;; functions for hash tables (Chapter 16)
 
-(defmacro dohash ((keyvar valuevar HTform &optional resultform) &body body
-                  &environment env)
-  (multiple-value-bind (body-rest declarations)
-      (system::parse-body body nil env)
+(defmacro dohash ((keyvar valuevar HTform &optional resultform) &body body)
+  (multiple-value-bind (body-rest declarations) (system::parse-body body)
     (let ((HTvar (gensym)))
       `(BLOCK NIL
          (LET ((,HTvar ,HTform))
@@ -500,7 +492,7 @@
               old-space1 old-space2 old-gccount)
   (macrolet ((diff4 (val1-n val2-n val1-o val2-o)
                (if (< internal-time-units-per-second 1000000)
-                 ;; TIME_1: AMIGA, OS/2, UNIX_TIMES
+                 ;; TIME_1: UNIX_TIMES
                  `(delta4 ,val1-n ,val2-n ,val1-o ,val2-o 16)
                  ;; TIME_2: other UNIX, WIN32
                  `(+ (* (- ,val1-n ,val1-o) internal-time-units-per-second)
@@ -535,19 +527,12 @@
   (if (and (realp time) (not (minusp time)))
     (progn
       ; Diese Fallunterscheidung hängt von sys::%sleep in time.d ab.
-      #+(or AMIGA OS/2 ACORN-RISCOS) ; SLEEP_1
-      (if (> time '#,(floor (expt 2 31) internal-time-units-per-second))
-        ; Mehr als 248 bzw. 994 bzw. 497 Tage? (Denn sys::%sleep akzeptiert nur
-        ; Argumente < 2^32, bei #+OS/2 sogar nur Argumente < 2^31.)
-        (loop ; ja -> Endlosschleife
-          (sys::%sleep '#,(* 86400 internal-time-units-per-second)))
-        (sys::%sleep (round (* time internal-time-units-per-second))))
-      #+UNIX ; SLEEP_2
+      #+UNIX
       (if (> time 16700000) ; mehr als 193 Tage?
         (loop (sys::%sleep 86400 0)) ; ja -> Endlosschleife
         (multiple-value-bind (seconds rest) (floor time)
           (sys::%sleep seconds (round (* rest 1000000)))))
-      #+WIN32 ; SLEEP_2
+      #+WIN32
       (if (> time 4250000) ; mehr als 49 Tage?
         (loop (sys::%sleep 86400 0)) ; ja -> Endlosschleife
         (multiple-value-bind (seconds rest) (floor time)
